@@ -45,6 +45,11 @@ brainvision_dir = IO_PATH / 'brainvision'
 openephys_dir = IO_PATH / 'openephys'
 ktlx_file = IO_PATH / 'xltek'
 mff_file = IO_PATH / 'egi.mff'
+moberg_file = IO_PATH / 'moberg'
+eeglab_1_file = IO_PATH / 'eeglab' / 'eeglab_example_one.set'
+eeglab_2_file = IO_PATH / 'eeglab' / 'eeglab_example_renamed.set'
+eeglab_hdf5_1_file = IO_PATH / 'eeglab' / 'eeglab_example_hdf5_one.set'
+eeglab_hdf5_2_file = IO_PATH / 'eeglab' / 'eeglab_example_hdf5.set'
 nev_file = IO_PATH / 'blackrock' / 'blackrock.nev'
 ns2_file = IO_PATH / 'blackrock' / 'blackrock.ns2'
 ns4_file = IO_PATH / 'blackrock' / 'sampleData.ns4'
@@ -65,6 +70,7 @@ fieldtrip_file = EXPORTED_PATH / 'fieldtrip.mat'
 wonambi_file = EXPORTED_PATH / 'exported.won'
 brainvision_file = EXPORTED_PATH / 'brainvision.vhdr'
 svg_file = EXPORTED_PATH / 'graphics_svg'
+bids_dir = EXPORTED_PATH / 'bids'
 
 # Store images
 DOCS_PATH = test_path.parent / 'docs'
