@@ -110,6 +110,7 @@ def test_events():
     assert len(annot.event_types) == 1
     assert len(annot.get_events()) == 0
     
+
 def test_epochs():
     d = Dataset(ns2_file)
     create_empty_annotations(annot_file, d)
@@ -119,13 +120,38 @@ def test_epochs():
     
     assert len(annot.get_epochs()) == 50
     assert len(annot.get_epochs(time=(1000,2000))) == 16
+    
+
+def test_get_cycles():
+    d = Dataset(ns2_file)
+    create_empty_annotations(annot_file, d)
+
+    annot = Annotations(annot_file)
+    annot.add_rater('test')
+    
+    annot.set_cycle_mrkr(510)
+    annot.set_cycle_mrkr(540)
+    annot.set_cycle_mrkr(570)
+    annot.set_cycle_mrkr(600, end=True)
+    
+    cycles = annot.get_cycles()
+    assert len(cycles) == 3
+    assert cycles[2] == (570, 600, 3)
+    
+    annot.remove_cycle_mrkr(510)
+    annot.clear_cycles()
+    
+    cycles = annot.get_cycles()
+    assert cycles is None
         
+
 def test_import_alice():
     annot = Annotations(annot_file)
     record_start = datetime(2000, 1, 1, 22, 55, 6)
     annot.import_staging(str(annot_alice_path), 'alice', 'alice', record_start)
     assert annot.time_in_stage('REM') == 5160
 
+
 def test_import_compumedics():
     annot = Annotations(annot_file)
     record_start = datetime(2000, 1, 1, 0, 0, 0)
@@ -134,6 +160,7 @@ def test_import_compumedics():
                          staging_start=record_start)
     assert annot.time_in_stage('REM') == 5970
 
+
 def test_import_domino():
     annot = Annotations(annot_file)
     record_start = datetime(2015, 9, 21, 21, 40, 30)
@@ -141,6 +168,7 @@ def test_import_domino():
                          record_start)
     assert annot.time_in_stage('REM') == 2460
 
+
 def test_import_remlogic():
     annot = Annotations(annot_file)
     record_start = datetime(2016, 8, 9, 22, 21, 30)
@@ -148,6 +176,7 @@ def test_import_remlogic():
                          record_start)
     assert annot.time_in_stage('REM') == 3420
 
+
 def test_import_sandman():
     annot = Annotations(annot_file)
     record_start = datetime(2010, 10, 10, 21, 3, 36)
@@ -155,6 +184,7 @@ def test_import_sandman():
                          record_start)
     assert annot.time_in_stage('REM') == 5610
 
+
 def test_import_fasst():
     annot = create_annotation(annot_fasst_export_file,
                               from_fasst=annot_fasst_path)
@@ -166,6 +196,8 @@ def test_import_fasst_error():
         create_annotation(annot_fasst_export_file,
                           from_fasst=ns2_file)
         
+
 def test_export_sleepstats():
     annot = Annotations(annot_psg_path)
-    assert annot.export_sleep_stats(annot_sleepstats_path, 0, 29000) == 338
+    assert annot.export_sleep_stats(annot_sleepstats_path, 0, 29000) == (338, 
+                                   36, 327)
