@@ -2,11 +2,9 @@
 """
 from logging import getLogger
 from bisect import bisect_left
-from csv import writer
+from csv import reader, writer
 from datetime import datetime, timedelta
-from itertools import compress
-from numpy import (allclose, around, asarray, in1d, isnan, logical_and, modf,
-                   nan)
+from numpy import allclose, around, asarray, isnan, logical_and, modf, nan
 from math import ceil, inf
 from os.path import splitext
 from pathlib import Path
@@ -15,6 +13,13 @@ from scipy.io import loadmat
 from xml.etree.ElementTree import Element, SubElement, tostring, parse
 from xml.dom.minidom import parseString
 
+try:
+    from PyQt5.QtCore import Qt
+    from PyQt5.QtWidgets import QProgressDialog
+except ImportError:
+    Qt = None
+    QProgressDialog = None
+
 from ..utils.exceptions import UnrecognizedFormat
 
 
@@ -1091,14 +1096,17 @@ class Annotations():
         -------
         list of tuple of float
             start and end times for each cycle, in seconds from recording start
+            and the cycle index starting at 1
         """
         cycles = self.rater.find('cycles')
 
         if not cycles:
             return None
 
-        starts = [float(mrkr.text) for mrkr in cycles.findall('cyc_start')]
-        ends = [float(mrkr.text) for mrkr in cycles.findall('cyc_end')]
+        starts = sorted(
+                [float(mrkr.text) for mrkr in cycles.findall('cyc_start')])
+        ends = sorted(
+                [float(mrkr.text) for mrkr in cycles.findall('cyc_end')])
         cyc_list = []
 
         if not starts or not ends:
@@ -1135,7 +1143,7 @@ class Annotations():
         return output
 
     def export(self, file_to_export, stages=True):
-        """Export annotations to csv file.
+        """Export epochwise annotations to csv file.
 
         Parameters
         ----------
@@ -1256,95 +1264,100 @@ class Annotations():
 
         return slp_onset_lat, waso, total_slp_time # for testing
 
-    def export_event_data(self, filename, summary, events, cycles=None,
-                          fsplit=None):
-        """Export event analysis data to CSV, from dialog.
-
+    def export_events(self, filename, evt_type):
+        """Export events to CSV
+        
         Parameters
         ----------
         filename : str
-            Filename for csv export.
-        summary : list of dict
-            Parameter name as key with global parameters/avgs as values. If
-            fsplit, there are two dicts, low frequency and high frequency
-            respectively, combined together in a list.
-        events : list of list of dict, optional
-            One dictionary per event, each containing  individual event
-            parameters. If fsplit, there are two event lists, low frequency
-            and high frequency respectively, combined together in a list.
-            Otherwise, there is a single list within the master list.
-        cycles: int, optional
-            Number of cycles.
-        fsplit: float, optional
-            Frequency at which to split dataset.
+            path of export file
+        evt_type : list of str
+            event types to export
         """
-        sheets = [filename]
-
-        if cycles:
-            sheets = [splitext(filename)[0] + '_cycle' + str(i + 1) + '.csv' \
-                      for i in range(len(cycles))]
-
-        if fsplit:
-            all_sheets = []
-
-            for fn in sheets:
-                all_sheets.extend([splitext(fn)[0] + '_slow.csv',
-                                   splitext(fn)[0] + '_fast.csv'])
-
-            sheets = all_sheets
-
-        ordered_params = ['dur', 'maxamp', 'ptp', 'peakf', 'power', 'rms',
-                          'count', 'density']
-        headings = ['Duration (s)',
-                    'Maximum amplitude (uV)',
-                    'Peak-to-peak amplitude (uV)',
-                    'Peak frequency (Hz)',
-                    'Average power (uV^2)',
-                    'RMS (uV)',
-                    'Count',
-                    'Density']
-        idx_params = in1d(ordered_params, list(summary[0].keys()))
-        sel_params_in_order = list(compress(ordered_params, idx_params))
-        per_evt_params = list(compress(ordered_params[:-2], idx_params))
-
-        lg.info('sheets: ' + str(len(sheets)) + ' summ: ' + str(len(summary)) + 'events: ' + str(len(events)))
-        if events is not None:
-            lg.info('number of events ' + str(len(events[0])))
-
-        for fn, summ, evs in zip(sheets, summary, events):
-            first_row = list(compress(headings, idx_params))
-            second_row = [summ[key][0] for key in sel_params_in_order]
-
-            if evs:
-                first_row[:0] = ['Index', 'Start (clock)', 'Start (record)',
-                                'End (record)', 'Channel', 'Stage']
-                second_row[:0] = ['Mean', '', '', '', '', '']
-                third_row = ['SD', '', '', '', '', ''] + \
-                        [summ[key][1] for key in per_evt_params]
-
-            with open(fn, 'w', newline='') as f:
-                lg.info('Writing to' + fn)
-                csv_file = writer(f)
-                csv_file.writerow(first_row)
-                csv_file.writerow(second_row)
-
-                if evs:
-                    csv_file.writerow(third_row)
-
-                    for i, ev in enumerate(evs):
-                        ev_time = (self.start_time +
-                                      timedelta(seconds=ev['start']))
-                        if isinstance(ev['chan'], (tuple, list)):
-                            ev['chan'] = ', '.join(ev['chan'])
-                        info_row = [i+1,
-                                    ev_time.strftime('%H:%M:%S'),
-                                    ev['start'],
-                                    ev['end'],
-                                    ev['chan'],
-                                    ev['stage']]
-                        data_row = [ev[key] for key in per_evt_params]
-                        csv_file.writerow(info_row + data_row)
+        filename = splitext(filename)[0] + '.csv'
+        headings_row = ['Index',
+                       'Start time',
+                       'End time',
+                       'Stitches',
+                       'Stage',
+                       'Cycle',
+                       'Event type',
+                       'Channel']
+        
+        events = []
+        for et in evt_type:
+            events.extend(self.get_events(name=et))
+            
+        events = sorted(events, key=lambda evt: evt['start'])
+        
+        if events is None:
+            lg.info('No events found.')
+            return
+        
+        with open(filename, 'w', newline='') as f:
+            lg.info('Writing to' + str(filename))
+            csv_file = writer(f)
+            csv_file.writerow(headings_row)
+            
+            for i, ev in enumerate(events):
+                csv_file.writerow([i + 1,
+                                   ev['start'],
+                                   ev['end'],
+                                   0,
+                                   ev['stage'],
+                                   '',
+                                   ev['name'],
+                                   ', '.join(ev['chan']),
+                                   ])
+            
+    def import_events(self, source_file, parent=None):
+        """Import events from Wonambi CSV event export and write to annot.
+        
+        Parameters
+        ----------
+        source_file : str
+            path to file CSV file
+        parent : QWidget
+            for GUI progress bar
+        """
+        events = []
+        
+        with open(source_file, 'r', encoding='utf-8') as csvfile:
+            csv_reader = reader(csvfile, delimiter=',')
+            
+            for row in csv_reader:
+                try:
+                    int(row[0])
+                    one_ev = {'name': row[6],
+                              'start': float(row[1]),
+                              'end': float(row[2]),
+                              'chan': row[7].split(', '),  # always a list
+                              'stage': row[4],
+                              'quality': 'Good'
+                              }
+                    events.append(one_ev)
+                    
+                except ValueError:
+                    continue
+                
+            if parent is not None:
+                progress = QProgressDialog('Saving events', 'Abort',
+                                   0, len(events) - 1, parent)
+                progress.setWindowModality(Qt.ApplicationModal)
+                
+            for i, one_ev in enumerate(events):
+                self.add_event(one_ev['name'],
+                                (one_ev['start'], one_ev['end']),
+                                chan=one_ev['chan'])
+                
+                if parent is not None:
+                    progress.setValue(i)                    
+                    if progress.wasCanceled():
+                        return
 
+        if parent is not None:
+            progress.close()
+        
 
 def update_annotation_version(xml_file):
     """Update the fields that have changed over different versions.
