@@ -10,8 +10,8 @@ from .filter import filter_, convolve
 from .select import (select, resample, get_times, _select_channels, fetch, 
                      Segments)
 from .frequency import frequency, timefrequency, band_power
-from .merge import concatenate, _merge_metadata
-from .math import math, get_descriptives, slopes
+from .merge import concatenate
+from .math import math, get_descriptives, event_params, export_event_params
 from .montage import montage
 from .peaks import peaks
 from .reject import rejectbadchan, remove_artf_evts
