@@ -93,6 +93,7 @@ class ConfigNotes(Config):
         self.index['marker_color'] = FormStr()
         self.index['annot_show'] = FormBool('Display User-Made Annotations')
         self.index['annot_bookmark_color'] = FormStr()
+        self.index['min_marker_display_dur'] = FormFloat()
         self.index['min_marker_dur'] = FormFloat()
 
         flayout = QFormLayout()
@@ -102,6 +103,8 @@ class ConfigNotes(Config):
         flayout.addRow(self.index['annot_show'])
         flayout.addRow('Color of bookmarks in annotations',
                            self.index['annot_bookmark_color'])
+        flayout.addRow('Event markers appear at least this long on trace',
+                       self.index['min_marker_display_dur'])
         flayout.addRow('Below this duration, markers and events have no '
                            'duration', self.index['min_marker_dur'])
 
@@ -261,6 +264,7 @@ class Notes(QTabWidget):
         tab_annot.setEditTriggers(QAbstractItemView.NoEditTriggers)
         go_to_annot = lambda r, c: self.go_to_marker(r, c, 'annot')
         tab_annot.cellDoubleClicked.connect(go_to_annot)
+        tab_annot.cellDoubleClicked.connect(self.reset_current_row)
 
         layout = QVBoxLayout()
         layout.addWidget(self.idx_eventtype_scroll, stretch=1)
@@ -419,14 +423,18 @@ class Notes(QTabWidget):
         act.triggered.connect(partial(self.import_staging, 'compumedics', 
                                       as_qual=True))
         actions['import_compumedics_qual'] = act
+        
+        act = QAction('Import events', self)
+        act.triggered.connect(self.import_events)
+        actions['imp_evt_csv'] = act
 
         act = QAction('Export staging', self)
         act.triggered.connect(self.export)
         actions['export'] = act
 
-        act = QAction('Brain Vision', self)
-        act.triggered.connect(partial(self.export_events, 'brainvision'))
-        actions['exp_evt_brainvision'] = act
+        act = QAction('Export events...', self)
+        act.triggered.connect(self.parent.show_export_events_dialog)
+        actions['export_events'] = act
 
         act = QAction('Spindle...', self)
         act.triggered.connect(self.parent.show_spindle_dialog)
@@ -626,7 +634,9 @@ class Notes(QTabWidget):
 
         # store information about the time as list (easy to access)
         marker_start = [mrk['start'] for mrk in markers]
+        marker_end = [mrk['end'] for mrk in markers]
         self.idx_marker.setProperty('start', marker_start)
+        self.idx_marker.setProperty('end', marker_end)
 
         if self.parent.traces.data is not None:
             self.parent.traces.display()
@@ -753,8 +763,10 @@ class Notes(QTabWidget):
         # store information about the time as list (easy to access)
         annot_start = [ann['start'] for ann in all_annot]
         annot_end = [ann['end'] for ann in all_annot]
+        annot_name = [ann['name'] for ann in all_annot]
         self.idx_annot_list.setProperty('start', annot_start)
         self.idx_annot_list.setProperty('end', annot_end)
+        self.idx_annot_list.setProperty('name', annot_name)
 
         if self.parent.traces.data is not None:
             self.parent.traces.display_annotations()
@@ -773,6 +785,11 @@ class Notes(QTabWidget):
                 self.annot.remove_bookmark(name=name, time=(start, end))
             else:
                 self.annot.remove_event(name=name, time=(start, end))
+                highlight = self.parent.traces.highlight
+                if highlight:
+                    self.parent.traces.scene.removeItem(highlight)
+                    highlight = None
+                    self.parent.traces.event_sel = None
 
         self.update_annotations()
 
@@ -790,13 +807,58 @@ class Notes(QTabWidget):
         """
         if table_type == 'dataset':
             marker_time = self.idx_marker.property('start')[row]
+            marker_end_time = self.idx_marker.property('end')[row]
         else:
             marker_time = self.idx_annot_list.property('start')[row]
+            marker_end_time = self.idx_annot_list.property('end')[row]
 
         window_length = self.parent.value('window_length')
-        window_start = floor(marker_time / window_length) * window_length
+        
+        if self.parent.traces.action['centre_event'].isChecked():
+            window_start = (marker_time + marker_end_time - window_length) / 2
+        else:
+            window_start = floor(marker_time / window_length) * window_length
+            
         self.parent.overview.update_position(window_start)
+        
+        if table_type == 'annot':
+            for annot in self.parent.traces.idx_annot:
+                if annot.marker.x() == marker_time:
+                    self.parent.traces.highlight_event(annot)
+                    break
 
+    def find_row(self, ev_start, ev_end):
+        """Highlight event row in table from start and end time.
+        
+        Parameters
+        ----------
+        ev_start : float
+            start time, in seconds from record start
+        ev_end : float
+            end time, in seconds from record start
+            
+        Returns
+        -------
+        int
+            index of event row in idx_annot_list QTableWidget
+        """
+        all_starts = self.idx_annot_list.property('start')
+        all_ends = self.idx_annot_list.property('end')
+        
+        for i, (start, end) in enumerate(zip(all_starts, all_ends)):
+            if start == ev_start and end == ev_end:
+                return i
+        
+        for i, start in enumerate(all_starts):
+            if start == ev_start:
+                return i
+            
+        for i, end in enumerate(all_ends):
+            if end == ev_end:
+                return i
+        
+        raise ValueError
+        
     def get_sleepstage(self, stage_idx=None):
         """Score the sleep stage, using shortcuts or combobox."""
         if self.annot is None:  # remove if buttons are disabled
@@ -1402,44 +1464,23 @@ class Notes(QTabWidget):
 
         self.annot.export(filename)
 
-    def export_events(self, source):
-        """Export events to external file of desired format."""
+    def import_events(self):
+        """action: import events from Wonambi CSV event export."""
         if self.annot is None:  # remove if buttons are disabled
             self.parent.statusBar().showMessage('No score file loaded')
             return
-        
-        name, ok = QInputDialog.getText(self, 'Choose Event Type',
-                                          'Enter event type to export')
-        
-        if not ok:
-            return
-        
-        if name not in self.annot.event_types:
-            self.parent.statusBar.showMessage('No such event type.')
-            return
-        
-        events = self.annot.get_events(name=name)
-        
-        if events is None:
-            self.parent.statusBar.showMessage('No events found.')
-            return
-        
-        fn, _ = QFileDialog.getSaveFileName(self, 'Export events', name)
+
+        fn, _ = QFileDialog.getOpenFileName(self, 'Import events',
+                                            None, 'CSV File (*.csv)')
         
         if fn == '':
             return
         
         fn = Path(fn).resolve()
-        
-        if 'brainvision' == source:
-            dataset = self.parent.info.dataset
-            data = ChanTime()
-            data.start_time = dataset.header['start_time']
-            data.s_freq = int(dataset.header['s_freq'])
-            
-            with fn.with_suffix('.vmrk').open('w') as f:
-                f.write(_write_vmrk(data, fn, events))
-        
+
+        self.annot.import_events(fn, parent=self.parent)
+        self.display_notes()        
+    
     def export_sleeps_stats(self):
         """action: export sleep statistics CSV."""
         if self.annot is None:  # remove if buttons are disabled
@@ -1498,6 +1539,10 @@ class Notes(QTabWidget):
         self.update_annotations()
 
         self.parent.create_menubar()  # remove all raters
+        
+    def reset_current_row(self):
+        """For traces.next_event"""
+        self.parent.traces.current_event_row = None
 
 
 class MergeDialog(QDialog):
@@ -1596,11 +1641,7 @@ class MergeDialog(QDialog):
                                      'Choose at least one event type.')
                 return
 
-            if not min_interval:
-                QMessageBox.warning(self, 'Missing information',
-                                     'Choose a minimum interval.')
-                return
-
+            min_interval = 0 if not min_interval else min_interval
 
             if self.merge_to == 'longer duration event':
                 merge_to_longer = True
@@ -1697,3 +1738,125 @@ class NewUserDialog(QDialog):
 
         elif button == self.idx_cancel:
             self.reject()
+
+
+class ExportEventsDialog(QDialog):
+    """Dialog for choosing export dataset options."""
+    def __init__(self, parent):
+        super().__init__(None, Qt.WindowSystemMenuHint | Qt.WindowTitleHint)
+        self.parent = parent
+        
+        self.setWindowTitle('Export events')
+        self.setWindowModality(Qt.WindowModal)
+        self.filename = None
+
+        self.create_dialog()
+
+    def create_dialog(self):
+        """Create the dialog."""
+        bbox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
+        self.idx_ok = bbox.button(QDialogButtonBox.Ok)
+        self.idx_cancel = bbox.button(QDialogButtonBox.Cancel)
+
+        filebutton = QPushButton()
+        filebutton.setText('Choose')
+        self.idx_filename = filebutton
+        
+        self.xp_format = FormMenu(['CSV', 'Brain Vision'])
+        self.all_types = FormBool('All event types')
+        
+        self.idx_evt_type = QListWidget()
+        self.idx_evt_type.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        
+        filebutton.clicked.connect(self.save_as)
+        self.all_types.connect(self.toggle_buttons)
+        bbox.clicked.connect(self.button_clicked)
+        
+        form = QFormLayout()
+        form.addRow('Filename', self.idx_filename)
+        form.addRow('Format', self.xp_format)
+        form.addRow(self.all_types)
+        form.addRow('Event type(s)', self.idx_evt_type)
+        
+        btnlayout = QHBoxLayout()
+        btnlayout.addStretch(1)
+        btnlayout.addWidget(bbox)
+
+        vlayout = QVBoxLayout()
+        vlayout.addLayout(form)
+        vlayout.addStretch(1)
+        vlayout.addLayout(btnlayout)
+
+        self.setLayout(vlayout)
+        
+    def button_clicked(self, button):
+        """Action when button was clicked.
+
+        Parameters
+        ----------
+        button : instance of QPushButton
+            which button was pressed
+        """
+        if button is self.idx_ok:            
+            fn = Path(self.filename)
+            xp_format = self.xp_format.get_value()
+            
+            if self.all_types.get_value():
+                evt_type = self.event_types
+            else:
+                evt_type = [
+                        x.text() for x in self.idx_evt_type.selectedItems()]
+                
+            if 'CSV' == xp_format:
+                                
+                self.parent.notes.annot.export_events(fn, evt_type)
+            
+            elif 'Brain Vision' == xp_format:
+                
+                events = []
+                for et in evt_type:                
+                    events.extend(self.parent.notes.annot.get_events(name=et))
+        
+                if not events:
+                    self.parent.statusBar.showMessage('No events found.')
+                    return
+                
+                dataset = self.parent.info.dataset
+                data = ChanTime()
+                data.start_time = dataset.header['start_time']
+                data.s_freq = int(dataset.header['s_freq'])
+                
+                with fn.with_suffix('.vmrk').open('w') as f:
+                    lg.info('Writing to ' + str(fn) + '.vmrk')
+                    f.write(_write_vmrk(data, fn, events))
+                
+            self.accept()
+            
+        if button is self.idx_cancel:
+            self.reject()
+        
+    def update(self):
+        """Update the event types list, info, when dialog is opened."""
+        self.filename = self.parent.notes.annot.xml_file
+        
+        self.event_types = self.parent.notes.annot.event_types
+        self.idx_evt_type.clear()
+        for ev in self.event_types:
+            self.idx_evt_type.addItem(ev)
+            
+    def toggle_buttons(self):
+        """Turn buttons on and off."""
+        all_types = self.all_types.get_value()
+        self.idx_evt_type.setEnabled(not all_types)
+    
+    def save_as(self):
+        """Dialog for getting name, location of dataset export."""
+        filename = splitext(self.filename)[0]
+        filename, _ = QFileDialog.getSaveFileName(self, 'Export events',
+                                                  filename)
+        if filename == '':
+            return
+
+        self.filename = filename
+        short_filename = short_strings(basename(self.filename))
+        self.idx_filename.setText(short_filename)
